## 0.1.9 - 2021-09-08

### Added

- Profession in ResumeData model
- Unified Error models

## 0.1.8 - 2021-09-06

### Fixed

- wait=true in API spec

## 0.1.7 - 2021-09-05

### Fixed

- Code samples naming conversion

## 0.1.6 - 2021-09-05

### Changed

- Description of some endpoints to match updats in API spec
- Moved samples to their own [./docs/samples_python.md](./docs/samples_python.md) file

## 0.1.5 - 2021-08-25

### Added

- Added flake, editorconfig, tox.ini etc files to match best practices for existing Draftable/Affinda projects (thanks
  @ralish!)

## 0.1.4 - 2021-08-18

### Fixed

- Update README.md to fix install instructions

## 0.1.3 - 2021-08-18

### Fixed

- Update README.md to hard link to github hosted logo to fix display on PyPi

## 0.1.2 - 2021-08-18

- Initial release

##### Follows the format from https://keepachangelog.com/en/1.0.0/
